@@ -32,7 +32,7 @@ class Enquiry(models.Model):
         return u'Enquiry from %s' % self.name
 
     def send(self):
-        subject = hasattr(settings, ENQUIRY_SUBJECT) and \
+        subject = hasattr(settings, 'ENQUIRY_SUBJECT') and \
             settings.ENQUIRY_SUBJECT or u"Contact Form Enquiry"
         message = EmailMessage(
             subject,
